/* please set your TABs to 4 to get proper formatting */

/*
         panteltje skin:
         program to calculate wire resistance including skin effect depending on frequency

         Copyright (C) Jan Panteltje 2009-always

 email: panteltje@yahoo.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/



#include <stdlib.h>
#include <stdio.h>
#include <math.h>


void calculate(double wire_diameter, double wire_length, double frequency, double *resistance)
{
/*
From:
 http://info.ee.surrey.ac.uk/Workshop/advice/coils/power_loss.html
R = 8.32 . 10-5 sqrt(f / DW)   ohms per metre
Where f is frequency (Hz), and DW the wire diameter (millimeters).  
*/

*resistance = (8.32 / 100000.0) * sqrt( (frequency / wire_diameter) ) * wire_length;
}


int main(int argc, char **argv)
{
double wire_diameter;
double wire_length;
double frequency;
double resistance;
char temp[80];


if(argc == 4)
	{
	wire_diameter	= atof(argv[1]);
	wire_length		= atof(argv[2]);
	frequency		= atof(argv[3]);
	}
else if(argc == 1)
	{
	fprintf(stdout, "skin-0.1 copyright Jan Panteltje 2009-always.\n");

	fprintf(stdout, "This program will calculate the extra resistance due to skin effect in a wire.\n");
 
	fprintf(stdout, "Wire diameter in mm?\n");
	fscanf(stdin, "%s", temp);
	wire_diameter	= atof(temp);

	fprintf(stdout, "Wire length in meter?\n");
	fscanf(stdin, "%s", temp);
	wire_length		= atof(temp);

	fprintf(stdout, "frequency in Hz?\n");
	fscanf(stdin, "%s", temp);
	frequency		= atof(temp);
	}
else
	{
	fprintf(stderr, "skin calculates the extra resistance in a wire due to skin effect.\n");
	fprintf(stderr, "Usage: skin wire_diameter(in mm) wire_length(in meter) frequency(in Hz)\nOr just type skin.\n"); 

	exit(1);
	}

calculate(wire_diameter, wire_length, frequency, &resistance);	

fprintf(stdout, "The extra resistance due to skin effect is %.4f Ohm.\n", (float)resistance);

exit(0);
} /* end function main */


